@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::AdditionalValidationChecks;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Email::Valid;
 use Scalar::Util qw(looks_like_number);
@@ -43,10 +43,10 @@ sub register {
     $validator->add_check( phone => sub {
         return 1 if !$_[2];
         return 0 if $_[2] =~ m{\A
-            (?: \+ | 00? ) [1-9]{1,3} # country
-            \s*? [1-9]{2,5} \s*?      # local
+            ((?: \+ | 00 ) [1-9]{1}[0-9]{0,2})? # country
+            \s*? [0-9]{2,5} \s*?      # local
             [/-]?
-            \s*? [0-9]{4,12}          # phone
+            \s*? [0-9]{2,12}          # phone
         \z}x;
         return 1;
     });
@@ -301,7 +301,7 @@ Mojolicious::Plugin::AdditionalValidationChecks
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -548,6 +548,16 @@ Some checks are inspired by L<https://github.com/chriso/validator.js>
 If you know some commonly used checks, please add an issue at
 L<https://github.com/reneeb/Mojolicious-Plugin-AdditionalValidationChecks/issues>.
 
+=head1 CONTRIBUTORS
+
+Those people contributed to this addon:
+
+=over 4
+
+=item * Florian Heyer
+
+=back
+
 =head1 SEE ALSO
 
 L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
